cal.GuestRole (Guest role) — amici1

# `cal.GuestRole` (Guest role)

GuestRole(id, ref, name, name_de, name_fr)

Master tables : cal.GuestRoles (Guest roles)

Slave tables : cal.GuestsByRole (Presences)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino_xl.lib.cal.models.GuestRole.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.cal.models.GuestRole.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.cal.models.GuestRole.overview`.

Referenced from cal.Guest.role, courses.Line.guest_role, system.SiteConfig.pupil_guestrole

## Database fields

Internal name | Verbose name | Help text
id | ID |
ref | Reference | The reference. This must be either empty or unique.
name | Designation |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |